Class: Dokkit::TaskLib::Clean

Inherits:
Object
  • Object
show all
Defined in:
lib/dokkit/tasklib/clean.rb

Overview

The Clean task library is a collection of rake tasks devoted to the cleaning of the documentation environment. The library defines a clean:output that remove the generated output folder (if exists). It defines also a clean:cache task that remove the cache folder (if exists).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(logger, configuration, namespace = 'clean') ⇒ Clean

Initialize the library with the logger instance, an optional namespace and configuration hash.



21
22
23
24
25
26
27
28
# File 'lib/dokkit/tasklib/clean.rb', line 21

def initialize(logger, configuration, namespace = 'clean')
  @namespace = namespace
  @logger = logger
  @configuration = configuration
  @output_dir = configuration[:output_dir]
  @cache_dir = configuration[:cache_dir]
  define_tasks
end

Instance Attribute Details

#cache_dirObject (readonly)

Returns the value of attribute cache_dir.



17
18
19
# File 'lib/dokkit/tasklib/clean.rb', line 17

def cache_dir
  @cache_dir
end

#output_dirObject (readonly)

Returns the value of attribute output_dir.



17
18
19
# File 'lib/dokkit/tasklib/clean.rb', line 17

def output_dir
  @output_dir
end